Index: src/heap.h |
diff --git a/src/heap.h b/src/heap.h |
index ceb8e274989c7cc67711bc093c80696192cca28a..82261eee381b42c8393801ad113c9ccc62434ff1 100644 |
--- a/src/heap.h |
+++ b/src/heap.h |
@@ -1075,11 +1075,11 @@ class Heap { |
Object* prototype, |
PretenureFlag pretenure = TENURED); |
- // Arguments object size. |
- static const int kArgumentsObjectSize = |
+ // Sloppy mode arguments object size. |
+ static const int kSloppyArgumentsObjectSize = |
JSObject::kHeaderSize + 2 * kPointerSize; |
// Strict mode arguments has no callee so it is smaller. |
- static const int kArgumentsObjectSizeStrict = |
+ static const int kStrictArgumentsObjectSize = |
JSObject::kHeaderSize + 1 * kPointerSize; |
// Indicies for direct access into argument objects. |
static const int kArgumentsLengthIndex = 0; |